---
name: Bug report
about: Topgrade is misbehaving
title: ''
labels: 'bug'
assignees: ''

---

<!--
Thanks for taking the time to fill out this bug report! 
Please make sure to 
[search for existing issues](https://github.com/topgrade-rs/topgrade/issues) 
before filing a new one!

Questions labeled with `Optional` can be skipped.
-->

<!-- 
If you're here to report about a "No asset found" error, please make sure that 
an hour has been passed since the last release was made. 
-->

## Erroneous Behavior
<!-- 
What actually happened?
-->

## Expected Behavior
<!-- 
Describe the expected behavior
-->

## Steps to reproduce
<!-- 
A minimal example to reproduce the issue
-->

## Possible Cause (Optional)
<!-- 
If you know the possible cause of the issue, please tell us.
-->

## Problem persists without calling from topgrade
<!-- 
Execute the erroneous command directly to see if the problem persists
-->
- [ ] Yes
- [ ] No

## Did you run topgrade through `Remote Execution`

- [ ] Yes
- [ ] No

If yes, does the issue still occur when you run topgrade directlly in your
remote host

- [ ] Yes
- [ ] No

## Configuration file (Optional)
<!-- 
Paste your configuration file inside the code block if you think this issue is 
related to configuration.
-->

```toml

```

## Additional Details
- Operation System/Version
  <!-- For example, Fedora Linux 38 -->

- Installation
  <!-- 
  How did you install topgrade: build from repo / crates.io (cargo install topgrade) 
  / package manager (which one) / other (describe)
  -->

- Topgrade version (`topgrade -V`)

## Verbose Output (`topgrade -v`)
<!-- 
Paste the verbose output into the pre-tags
-->

<details>
<pre>

</pre>
</details>
